var namespaces_dup =
[
    [ "Steinberg", "namespaceSteinberg.html", "namespaceSteinberg" ],
    [ "VST3", "namespaceVST3.html", "namespaceVST3" ],
    [ "VSTGUI", "namespaceVSTGUI.html", [
      [ "soHandle", "namespaceVSTGUI.html#acfe0fc5dd43523202fab9c1ec6ef4e42", null ]
    ] ]
];